package com.hc.business.mapper;

import com.hc.business.dto.ClassPrintDto;
import com.hc.business.model.ClassConfig;
import com.hc.core.utils.mapper.Mapper;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 班次表(ClassConfig)表数据库访问层
 *
 * @author java
 * @since 2020-11-19 16:12:30
 */

@Repository
public interface ClassConfigMapper extends Mapper<ClassConfig> {

    /**
     * 条件查询培训班
     *
     * @param valid 是否上线
     * @return 实例对象数组
     */
    List<ClassConfig> queryByValid(Integer valid);

    /**
     * 地区id查询培训班
     *
     * @param areaId 地区id
     * @return 实例对象数组
     */
    List<ClassConfig> queryByAreaId(Integer areaId);

    /**
     * 培训班名称查询培训班
     *
     * @param name 培训班名称
     * @return 实例对象数组
     */
    List<ClassConfig> queryByClassName(String name);

    /**
     * 依据开始时间查询班次
     *
     * @param studyStartTime
     * @return
     */
    List<ClassConfig> queryByTime(Long studyStartTime);

    /**
     * 获取全部的培训班
     *
     * @return 实例对象数组
     */
    List<ClassConfig> queryAll();


    /**
     * 依据开年度查询班次
     *
     * @param year
     * @return
     */
    List<ClassConfig> queryByYear(String year);

    /**
     * 依据目标人群查询班次
     *
     * @param target
     * @return
     */
    List<ClassConfig> queryByTarget(String target);

    List<ClassPrintDto> getPrintList(String cardId);
}