package com.hc.business.mapper;

import com.hc.business.dto.UserInvoiceDto;
import com.hc.business.model.UserInvoices;
import com.hc.core.utils.mapper.Mapper;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 用户发票表(UserInvoices)表数据库访问层
 *
 * @author java
 * @since 2020-12-02 10:50:34
 */

@Repository
public interface UserInvoicesMapper extends Mapper<UserInvoices> {

    /**
     * @Author ymnets
     * @Description 根据流水号查询到发票
     * @return com.hc.business.model.UserInvoices
     **/
    UserInvoices queryBySyncSerialNum(String syncSerialNum);

    /**
     * @Author ymnets
     * @Description 根据发票代码获取发票
     * @return
     **/
    UserInvoices queryByFPCode(String fpCode);

    /**
     * @Author ymnets
     * @Description 根据订单号（诺诺订单号）
     * @return
     **/
    UserInvoices queryBySyncOrderNo(String syncOrderNo);
    /**
     * 获取用户发票信息
     *
     * @param userId 用户id
     * @return 实例对象数组
     */
    List<UserInvoices> queryDetailByUserId(Integer userId);

    /**
     * 查询有效发票
     *
     * @return 实例对象数组
     */
    List<UserInvoices> queryAll();

    /**
     * 获取班次发票信息
     *
     * @param classId 班次id
     * @return 实例对象数组
     */
    List<UserInvoices> queryByClassId(Integer classId);

    /**
     * 获取班次发票信息
     *
     * @param orderId 班次id
     * @return 实例对象数组
     */
    List<UserInvoices> queryByOrderId(Integer orderId,Integer syncStatus);

    /**
     * 获取状态获取发票信息
     *
     * @param status 状态
     * @return 实例对象数组
     */
    List<UserInvoices> queryByStatus(Integer status);

    List<UserInvoiceDto> queryAllInvoices(String orderNo, Long begin, Long end);

}