package com.hc.business.service;

import com.github.pagehelper.PageInfo;
import com.hc.business.dto.UserStatusClassDto;
import com.hc.business.model.UserStatus;
import org.springframework.stereotype.Component;

import java.util.List;


/**
 * 用户班级学习进度表
 * (UserStatus)表服务接口
 *
 * @author java
 * @since 2020-12-06 11:26:43
 */

@Component
public interface UserStatusService {

    /**
     * 通过ID查询单条数据
     *
     * @param statusId 主键
     * @return 实例对象
     */
    UserStatus queryById(Integer statusId);

    /**
     * 新增数据
     *
     * @param userStatus 实例对象
     * @return 实例对象
     */
    UserStatus insert(UserStatus userStatus);

    /**
     * 修改数据
     *
     * @param userStatus 实例对象
     * @return 实例对象
     */
    UserStatus update(UserStatus userStatus);

    /**
     * 通过主键删除数据
     *
     * @param statusId 主键
     * @return 是否成功
     */
    boolean deleteById(Integer statusId);

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    PageInfo queryAllByLimit(int page, int size);

    /**
     * 查询用户培训记录
     *
     * @param userId 用户id
     * @return 实例对象数组
     */
    List<UserStatusClassDto> queryDtoByUserId(Integer userId);


    /**
     * 查询班次下的用户
     *
     * @param classId 班次id
     * @param page    页码
     * @param size    查询条数
     * @return 实例对象
     */
    PageInfo queryByClassId(Integer classId, int page, int size);

    List<UserStatus> queryAvailableByClassId(Integer classId);
}