package com.hc.business.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.business.dto.OrderRefundLogDto;
import com.hc.business.mapper.OrderRefundLogMapper;
import com.hc.business.model.OrderRefundLog;
import com.hc.business.service.OrderRefundLogService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 退费用户明细表(OrderRefundLog)表服务实现类
 *
 * @author makejava
 * @since 2024-01-20 10:54:50
 */

@Service("orderRefundLogService")
public class OrderRefundLogServiceImpl implements OrderRefundLogService {

    private final OrderRefundLogMapper orderRefundLogMapper;

    public OrderRefundLogServiceImpl(OrderRefundLogMapper orderRefundLogMapper) {
        this.orderRefundLogMapper = orderRefundLogMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param logId 主键
     * @return 实例对象
     */
    @Override
    public OrderRefundLog queryById(Integer logId) {
        return this.orderRefundLogMapper.selectByPrimaryKey(logId);
    }

    /**
     * 新增数据
     *
     * @param orderRefundLog 实例对象
     * @return 实例对象
     */
    @Override
    public OrderRefundLog insert(OrderRefundLog orderRefundLog) {
        this.orderRefundLogMapper.insert(orderRefundLog);
        return orderRefundLog;
    }

    /**
     * 修改数据
     *
     * @param orderRefundLog 实例对象
     * @return 实例对象
     */
    @Override
    public OrderRefundLog update(OrderRefundLog orderRefundLog) {
        this.orderRefundLogMapper.updateByPrimaryKeySelective(orderRefundLog);
        return this.queryById(orderRefundLog.getLogId());
    }

    /**
     * 通过主键删除数据
     *
     * @param logId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer logId) {
        return this.orderRefundLogMapper.deleteByPrimaryKey(logId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.orderRefundLogMapper::selectAll);
    }

    /**
     * @Author ymnets
     * @Description 根据退费单ID查询退费详情
     * @return java.util.List<com.hc.business.dto.OrderRefundLogDto>
     **/
    @Override
    public List<OrderRefundLogDto> queryByRefundId(Integer refundId){
        return orderRefundLogMapper.queryByRefundId(refundId);
    }

    /**
     * @Author ymnets
     * @Description 获取可以退费的用户，并且这些用户没有退费过或者正在退费
     * @return java.util.List<com.hc.business.dto.OrderRefundLogDto>
     **/
    @Override
    public List<OrderRefundLogDto> getWaitingForRefundUser(Integer orderId){
        return orderRefundLogMapper.getWaitingForRefundUser(orderId);
    }
}
