package com.hc.gpweb.controller.back;


import com.hc.gpbusiness.model.WebCourse;
import com.hc.gpbusiness.model.WebCourseType;
import com.hc.gpbusiness.service.WebCourseService;
import com.hc.gpbusiness.service.WebCourseTypeService;
import com.hc.gpcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * 课程分类(CourseType)表控制层
 *
 * @author java
 * @since 2020-07-29 16:23:06
 */

@RestController
@RequestMapping("/api/back/courseType")
public class BackCourseTypeController {

    /**
     * 服务对象
     */
    private final WebCourseTypeService courseTypeService;

    public BackCourseTypeController(WebCourseTypeService courseTypeService) {
        this.courseTypeService = courseTypeService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 分类", response = Result.class)
    public Result selectBackCourse(@PathVariable("id") Integer id) {
        return Result.success(this.courseTypeService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 分类", response = Result.class)
    public Result addBackCourse(@Valid @RequestBody WebCourseType course) {
        return Result.success(courseTypeService.insert(course));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 分类", response = Result.class)
    public Result updateBackCourse(@RequestBody WebCourseType course) {
        return Result.success(courseTypeService.update(course));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 分类", response = Result.class)
    public Result deleteBackCourse(@PathVariable("id") Integer id) {
        return Result.success(courseTypeService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 Course列表(分页)", response = Result.class)
    public Result listBackCourse(@RequestParam(defaultValue = "0") Integer page,
                                 @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(courseTypeService.queryAllByLimit(page, size));
    }


}